@@ -169,6 +169,7 @@ void MainWindow::doOpenFile()
   {
     openFile( fileName );  
   }
+
 }
 
 void MainWindow::doOpenTableOfContents()
@@ -194,9 +195,12 @@ void MainWindow:: doFullScreenOn()
 {
   if( !fullScreenMode_ )
   {
+    
+#ifdef STD_TRACING
     std::cout << __PRETTY_FUNCTION__ 
               << ": full screen ON"
               << std::endl;
+#endif
     
     toolBar_->hide();
 
@@ -219,9 +223,12 @@ void MainWindow:: doFullScreenOff()
 {
   if( fullScreenMode_ )
   {
+#ifdef STD_TRACING
     std::cout << __PRETTY_FUNCTION__ 
               << ": full screen OFF"
               << std::endl;
+#endif
+
     pageView_->move(0,notificationAreaHeight());
     pageView_->setMinimumSize( pageSize_ );
     pageView_->setMaximumSize( pageSize_ );
@@ -239,25 +246,37 @@ void MainWindow:: doFullScreenOff()
 
 void MainWindow:: doPrevPage()
 {
+#ifdef STD_TRACING
   std::cout << __PRETTY_FUNCTION__ << std::endl;
+#endif  
+  toolBar_->enableButtons( false );
   pageView_->prevPage();
+  toolBar_->enableButtons( true );
 }
 
 void MainWindow:: doNextPage()
 {
+#ifdef STD_TRACING
   std::cout << __PRETTY_FUNCTION__ << std::endl;
+#endif  
+  toolBar_->enableButtons( false );
   pageView_->nextPage();
+  toolBar_->enableButtons( true );
 }
 
 void MainWindow:: doZoomIn()
 {
+#ifdef STD_TRACING
   std::cout << __PRETTY_FUNCTION__ << std::endl;
+#endif  
   pageView_->zoomIn();
 }
 
 void MainWindow:: doZoomOut()
 {
+#ifdef STD_TRACING
   std::cout << __PRETTY_FUNCTION__ << std::endl;
+#endif
   pageView_->zoomOut();
 }
 
@@ -268,7 +287,9 @@ void MainWindow::pickedContent()
 
   size_t row = contents_->currentRow(); 
   contents_->hide();
+  toolBar_->enableButtons( false );
   pageView_->openPageNum( row );
+  toolBar_->enableButtons( true );
 }
 
 void MainWindow::minimizeApplication()
