@@ -23,6 +23,7 @@
 #include <QColor>
 #include <libchmurlfactory.h>
 #include "pageviewwidget.h"
+#include "mainwindow.h"
 
 using namespace std;
 
@@ -57,23 +58,34 @@ void PageViewWidget::openPageNum( size_t page )
 
   size_t sz = static_cast<size_t>(tableOfContents_.size());
 
+#ifdef STD_TRACING
     std::cout << __PRETTY_FUNCTION__ 
               << ": request to move from page :" 
               << page_
               << " to page :"
               << page
               << std::endl;
-
+#endif
   if ( page && page < static_cast<size_t>(tableOfContents_.size()) )
   {
     QString url = tableOfContents_[page].urls.join("|");
+    
+    MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
+    if ( wnd )
+    {
+      wnd->setWindowTitle( QString(tableOfContents_[page].name) );
+    }
+    // setTitle( "KChmViewer @" +tableOfContents_[page].name );
+    
     openPage( url );
     page_ = page;
 
+#ifdef STD_TRACING
     std::cout << __PRETTY_FUNCTION__ 
               << ": new page :" 
               << page_
               << std::endl;
+#endif    
   }
 }
 
@@ -85,25 +97,41 @@ bool PageViewWidget::openPage( const QString& url )
 {
   bool result = true;
   
-    std::cout << __PRETTY_FUNCTION__ 
+#ifdef STD_TRACING  
+  std::cout << __PRETTY_FUNCTION__ 
               << " : decoding url"
               << std::endl;
+#endif
+    
+  makeURLabsolute( url, true );
   QString decodedUrl = decodeUrl( url );
-    std::cout << __PRETTY_FUNCTION__ 
+
+  
+#ifdef STD_TRACING  
+  std::cout << __PRETTY_FUNCTION__ 
+              << " : "
+              << decodedUrl.toStdString()
               << " : setting source"
               << std::endl;
-  
+#endif  
   // call into baseclass: QTextBrowsr
   setSource( decodedUrl );
   
-    std::cout << __PRETTY_FUNCTION__ 
+#ifdef STD_TRACING  
+  std::cout << __PRETTY_FUNCTION__ 
               << " : reloading"
               << std::endl;
+#endif    
+
   reload();
-    std::cout << __PRETTY_FUNCTION__ 
+  
+#ifdef STD_TRACING  
+  std::cout << __PRETTY_FUNCTION__ 
               << " : done"
               << std::endl;
+#endif
 
+    
   return result;
 }
 
@@ -154,12 +182,19 @@ bool PageViewWidget::loadChmFile( const QString& filename )
 
   if ( loaded )
   {
+    baseUrl_ = "/";
     tableOfContents_.clear(); 
     chm_->parseTableOfContents( &tableOfContents_ );
 
 
     if ( tableOfContents_.size()  )
     {
+      MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
+      if ( wnd )
+      {
+        wnd->setWindowTitle( QString(tableOfContents_[0].name) );
+      }
+
       openPage( tableOfContents_[0].urls.join("|") );
     }
   }
@@ -173,7 +208,9 @@ QVariant PageViewWidget::loadResource(int type, const QUrl & name)
 {
 	QString data, file, path = name.toString( QUrl::StripTrailingSlash );
 
-//  std::cout << __PRETTY_FUNCTION__ << ":" << name.toString().toStdString() << std::endl;
+#ifdef STD_TRACING  
+  std::cout << "loadResource :" << name.toString().toStdString() << std::endl;
+#endif  
 	// Retreive the data from chm file
 
 	if ( !chm_ )
@@ -185,14 +222,26 @@ QVariant PageViewWidget::loadResource(int type, const QUrl & name)
 	
 	path = makeURLabsolute( path, false );
 
+#ifdef STD_TRACING  
+  std::cout << "loadResource : abs url:" << path.toStdString() << std::endl;
+#endif  
 	// To handle a single-image pages, we need to generate the HTML page to show 
 	// this image. We did it in KCHMViewWindow::handleStartPageAsImage; now we need
 	// to generate the HTML page, and set it.
 	if ( LCHMUrlFactory::handleFileType( path, data ) )
 		return QVariant( QString( data ) );
 	
+#ifdef STD_TRACING  
+  std::cout << "loadResource : type" << type << std::endl;
+#endif  
+
 	if ( type == QTextDocument::HtmlResource || type == QTextDocument::StyleSheetResource )
 	{
+
+#ifdef STD_TRACING    
+    std::cout << "loadResource : html or css , path:" << path.toStdString() << std::endl;
+#endif
+
 		if ( !chm_->getFileContentAsString( &data, path ) )
 			qWarning( "Needed file %s is not present in this CHM archive\n", qPrintable( path ) );
 
@@ -209,11 +258,22 @@ QVariant PageViewWidget::loadResource(int type, const QUrl & name)
 		
 		QString fpath = decodeUrl( path );
 		
+#ifdef STD_TRACING
+    std::cout << "loadResource : image , path:" << fpath.toStdString() << std::endl;
+#endif    
 		if ( chm_->getFileContentAsBinary( &buf, fpath ) )
 		{
 			if ( !img.loadFromData ( (const uchar *) buf.data(), buf.size() ) )
+      {
 				qWarning( "Needed file %s is not present in this CHM archive\n", qPrintable( path ) );
+      }
 		}
+    else
+    {
+#ifdef STD_TRACING
+      std::cout << "loadResource : image , binary load failed." << std::endl;
+#endif      
+    }
 		
 		return QVariant( img );
 	}
@@ -238,7 +298,16 @@ QString PageViewWidget::makeURLabsolute ( const QString & url, bool set_as_base
 	
 		newurl = QDir::cleanPath (newurl);
 
-		if ( set_as_base )
+#ifdef STD_TRACING
+    std::cout << "PageViewWidget::makeURLabsolute :"
+              << " base url : "
+              << baseUrl_.toStdString()
+              << ", newurl :"
+              << newurl.toStdString()
+              << std::endl;
+#endif
+
+		if ( set_as_base  )
 		{
 			baseUrl_ = newurl;
 		
@@ -246,10 +315,22 @@ QString PageViewWidget::makeURLabsolute ( const QString & url, bool set_as_base
 			int i = newurl.lastIndexOf('/');
 			if ( i != -1 )
 				baseUrl_ = QDir::cleanPath (newurl.left (i + 1));
+#ifdef STD_TRACING
+      std::cout << "PageViewWidget::makeURLabsolute :"
+                  << " new base url : "
+                  << baseUrl_.toStdString()
+                  << std::endl;
+#endif      
 		}
 	}
 
-	//qDebug ("ViewWindow::makeURLabsolute (%s) -> (%s)", url.ascii(), newurl.ascii());
+#ifdef STD_TRACING
+  std::cout << "PageViewWidget::makeURLabsolute ("
+            << url.toStdString()
+            << ") --> ("
+            << newurl.toStdString()
+            << ")" << std::endl;
+#endif  
 	return newurl;
 }
 
